@@ -1,15 +1,22 @@
 use strict;
 use warnings;
 package IPC::Lockfile;
-$IPC::Lockfile::VERSION = '0.01';
+$IPC::Lockfile::VERSION = '0.02';
 # ABSTRACT: run only one instance of a program at a time using flock
 use Fcntl qw(:flock);
 
-flock DATA, LOCK_EX|LOCK_NB or die "$0 is running!\n";;
+my $filepath = "$0.lock";
+
+# lexical filehandles dont work!
+open LOCKFILE, '>', $filepath
+  or die "Unable to create the lockfile $filepath $!\n";
+flock LOCKFILE, LOCK_EX|LOCK_NB or die "$0 is running!\n";;
 
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -20,7 +27,7 @@ IPC::Lockfile - run only one instance of a program at a time using flock
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -31,7 +38,16 @@ Just import the module:
 
     ... # program code here
 
-No external lockfile is created, C<IPC::Lockfile> uses C<_DATA_> (See L<#THANKS>).
+This will create a lockfile in the same directory as the program. To avoid
+race conditions, the file will not be deleted when the program ends.
+
+Or do not use this module and just add these two lines to your program:
+
+  use Fcntl qw(:flock);
+  flock DATA, LOCK_EX|LOCK_NB or die "$0 is running!\n";;
+
+No external lockfile is created as it uses C<_DATA_>. An elegant L<solution|http://perl.plover.com/yak/flock/samples/slide006.html>
+for lockfiles proposed by Mark Jason Dominus.
 
 =head1 DESCRIPTION
 
@@ -39,10 +55,6 @@ C<IPC::Lockfile> is a module for use with Perl programs when you only want one
 instance of the script to run at a time. It uses C<flock> and should work if
 run on an OS that supports C<flock> (e.g. Linux, BSD, OSX and Windows).
 
-=head1 THANKS
-
-This module implements an elegant L<solution|http://perl.plover.com/yak/flock/samples/slide006.html> to lockfiles proposed by Mark Jason Dominus.
-
 =head1 SEE ALSO
 
 L<IPC::Pidfile> for a PID-based solution that relies on signals and has a race
@@ -61,5 +73,3 @@ This is free software, licensed under:
   The (two-clause) FreeBSD License
 
 =cut
-
-__DATA__
\ No newline at end of file
